@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     BackupJobStateType,
@@ -182,7 +182,7 @@ AdvancedBackupSettingTypeDef = TypedDict(
     "AdvancedBackupSettingTypeDef",
     {
         "ResourceType": str,
-        "BackupOptions": Dict[str, str],
+        "BackupOptions": Mapping[str, str],
     },
     total=False,
 )
@@ -218,13 +218,13 @@ _RequiredBackupPlanInputTypeDef = TypedDict(
     "_RequiredBackupPlanInputTypeDef",
     {
         "BackupPlanName": str,
-        "Rules": List["BackupRuleInputTypeDef"],
+        "Rules": Sequence["BackupRuleInputTypeDef"],
     },
 )
 _OptionalBackupPlanInputTypeDef = TypedDict(
     "_OptionalBackupPlanInputTypeDef",
     {
-        "AdvancedBackupSettings": List["AdvancedBackupSettingTypeDef"],
+        "AdvancedBackupSettings": Sequence["AdvancedBackupSettingTypeDef"],
     },
     total=False,
 )
@@ -293,8 +293,8 @@ _OptionalBackupRuleInputTypeDef = TypedDict(
         "StartWindowMinutes": int,
         "CompletionWindowMinutes": int,
         "Lifecycle": "LifecycleTypeDef",
-        "RecoveryPointTags": Dict[str, str],
-        "CopyActions": List["CopyActionTypeDef"],
+        "RecoveryPointTags": Mapping[str, str],
+        "CopyActions": Sequence["CopyActionTypeDef"],
         "EnableContinuousBackup": bool,
     },
     total=False,
@@ -342,8 +342,8 @@ _RequiredBackupSelectionTypeDef = TypedDict(
 _OptionalBackupSelectionTypeDef = TypedDict(
     "_OptionalBackupSelectionTypeDef",
     {
-        "Resources": List[str],
-        "ListOfTags": List["ConditionTypeDef"],
+        "Resources": Sequence[str],
+        "ListOfTags": Sequence["ConditionTypeDef"],
     },
     total=False,
 )
@@ -409,9 +409,9 @@ ControlInputParameterTypeDef = TypedDict(
 ControlScopeTypeDef = TypedDict(
     "ControlScopeTypeDef",
     {
-        "ComplianceResourceIds": List[str],
-        "ComplianceResourceTypes": List[str],
-        "Tags": Dict[str, str],
+        "ComplianceResourceIds": Sequence[str],
+        "ComplianceResourceTypes": Sequence[str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -466,7 +466,7 @@ _RequiredCreateBackupPlanInputRequestTypeDef = TypedDict(
 _OptionalCreateBackupPlanInputRequestTypeDef = TypedDict(
     "_OptionalCreateBackupPlanInputRequestTypeDef",
     {
-        "BackupPlanTags": Dict[str, str],
+        "BackupPlanTags": Mapping[str, str],
         "CreatorRequestId": str,
     },
     total=False,
@@ -533,7 +533,7 @@ _RequiredCreateBackupVaultInputRequestTypeDef = TypedDict(
 _OptionalCreateBackupVaultInputRequestTypeDef = TypedDict(
     "_OptionalCreateBackupVaultInputRequestTypeDef",
     {
-        "BackupVaultTags": Dict[str, str],
+        "BackupVaultTags": Mapping[str, str],
         "EncryptionKeyArn": str,
         "CreatorRequestId": str,
     },
@@ -561,7 +561,7 @@ _RequiredCreateFrameworkInputRequestTypeDef = TypedDict(
     "_RequiredCreateFrameworkInputRequestTypeDef",
     {
         "FrameworkName": str,
-        "FrameworkControls": List["FrameworkControlTypeDef"],
+        "FrameworkControls": Sequence["FrameworkControlTypeDef"],
     },
 )
 _OptionalCreateFrameworkInputRequestTypeDef = TypedDict(
@@ -569,7 +569,7 @@ _OptionalCreateFrameworkInputRequestTypeDef = TypedDict(
     {
         "FrameworkDescription": str,
         "IdempotencyToken": str,
-        "FrameworkTags": Dict[str, str],
+        "FrameworkTags": Mapping[str, str],
     },
     total=False,
 )
@@ -602,7 +602,7 @@ _OptionalCreateReportPlanInputRequestTypeDef = TypedDict(
     "_OptionalCreateReportPlanInputRequestTypeDef",
     {
         "ReportPlanDescription": str,
-        "ReportPlanTags": Dict[str, str],
+        "ReportPlanTags": Mapping[str, str],
         "IdempotencyToken": str,
     },
     total=False,
@@ -941,7 +941,7 @@ _RequiredFrameworkControlTypeDef = TypedDict(
 _OptionalFrameworkControlTypeDef = TypedDict(
     "_OptionalFrameworkControlTypeDef",
     {
-        "ControlInputParameters": List["ControlInputParameterTypeDef"],
+        "ControlInputParameters": Sequence["ControlInputParameterTypeDef"],
         "ControlScope": "ControlScopeTypeDef",
     },
     total=False,
@@ -1526,7 +1526,7 @@ PutBackupVaultNotificationsInputRequestTypeDef = TypedDict(
     {
         "BackupVaultName": str,
         "SNSTopicArn": str,
-        "BackupVaultEvents": List[BackupVaultEventType],
+        "BackupVaultEvents": Sequence[BackupVaultEventType],
     },
 )
 
@@ -1590,7 +1590,7 @@ _OptionalReportDeliveryChannelTypeDef = TypedDict(
     "_OptionalReportDeliveryChannelTypeDef",
     {
         "S3KeyPrefix": str,
-        "Formats": List[str],
+        "Formats": Sequence[str],
     },
     total=False,
 )
@@ -1695,8 +1695,8 @@ _OptionalStartBackupJobInputRequestTypeDef = TypedDict(
         "StartWindowMinutes": int,
         "CompleteWindowMinutes": int,
         "Lifecycle": "LifecycleTypeDef",
-        "RecoveryPointTags": Dict[str, str],
-        "BackupOptions": Dict[str, str],
+        "RecoveryPointTags": Mapping[str, str],
+        "BackupOptions": Mapping[str, str],
     },
     total=False,
 )
@@ -1785,7 +1785,7 @@ _RequiredStartRestoreJobInputRequestTypeDef = TypedDict(
     "_RequiredStartRestoreJobInputRequestTypeDef",
     {
         "RecoveryPointArn": str,
-        "Metadata": Dict[str, str],
+        "Metadata": Mapping[str, str],
         "IamRoleArn": str,
     },
 )
@@ -1824,7 +1824,7 @@ TagResourceInputRequestTypeDef = TypedDict(
     "TagResourceInputRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -1832,7 +1832,7 @@ UntagResourceInputRequestTypeDef = TypedDict(
     "UntagResourceInputRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeyList": List[str],
+        "TagKeyList": Sequence[str],
     },
 )
 
@@ -1866,7 +1866,7 @@ _OptionalUpdateFrameworkInputRequestTypeDef = TypedDict(
     "_OptionalUpdateFrameworkInputRequestTypeDef",
     {
         "FrameworkDescription": str,
-        "FrameworkControls": List["FrameworkControlTypeDef"],
+        "FrameworkControls": Sequence["FrameworkControlTypeDef"],
         "IdempotencyToken": str,
     },
     total=False,
@@ -1892,7 +1892,7 @@ UpdateFrameworkOutputTypeDef = TypedDict(
 UpdateGlobalSettingsInputRequestTypeDef = TypedDict(
     "UpdateGlobalSettingsInputRequestTypeDef",
     {
-        "GlobalSettings": Dict[str, str],
+        "GlobalSettings": Mapping[str, str],
     },
     total=False,
 )
@@ -1934,7 +1934,7 @@ UpdateRecoveryPointLifecycleOutputTypeDef = TypedDict(
 UpdateRegionSettingsInputRequestTypeDef = TypedDict(
     "UpdateRegionSettingsInputRequestTypeDef",
     {
-        "ResourceTypeOptInPreference": Dict[str, bool],
+        "ResourceTypeOptInPreference": Mapping[str, bool],
     },
     total=False,
 )
